@@ -11,7 +11,7 @@ use Lemonldap::NG::Handler::Main::Logger;
 use Lemonldap::NG::Handler::API qw(:httpCodes);
 use Lemonldap::NG::Common::Crypto;
 
-our $VERSION = '1.9.1';
+our $VERSION = '1.9.4';
 
 ## @imethod void configReload(hashRef conf, hashRef tsv)
 # Given a Lemonldap::NG configuration $conf, computes values used to
@@ -108,10 +108,10 @@ sub defaultValuesInit {
 
     $tsv->{$_} = $conf->{$_} foreach (
         qw(
-        cda              cookieExpiration    cookieName
-        customFunctions  httpOnly            securedCookie
-        timeoutActivity  useRedirectOnError  useRedirectOnForbidden
-        useSafeJail      whatToTrace
+        cda                    cookieExpiration cookieName
+        customFunctions        httpOnly         securedCookie
+        timeout                timeoutActivity  useRedirectOnError
+        useRedirectOnForbidden useSafeJail      whatToTrace
         )
     );
 
@@ -376,37 +376,36 @@ sub conditionSub {
         eval 'use Apache2::Filter' unless ( $INC{"Apache2/Filter.pm"} );
         return (
             sub {
-                my $r = shift;
-                $r->add_output_filter(
+                $Lemonldap::NG::Handler::API::ApacheMP2::request
+                  ->add_output_filter(
                     sub {
                         return Lemonldap::NG::Handler::Main->redirectFilter( $u,
                             @_ );
                     }
-                );
+                  );
                 1;
             },
             0
         );
     }
     elsif ( $cond =~ /^logout_app_sso(?:\s+(.*))?$/i ) {
-        eval 'use Apache2::Filter' unless ( $INC{"Apache2/Filter.pm"} );
         my $u = $1 || &{ $tsv->{portal} }();
+        eval 'use Apache2::Filter' unless ( $INC{"Apache2/Filter.pm"} );
         return (
             sub {
-                my $r = shift;
                 Lemonldap::NG::Handler::Main->localUnlog;
-                $r->add_output_filter(
+                $Lemonldap::NG::Handler::API::ApacheMP2::request
+                  ->add_output_filter(
                     sub {
-                        my $r = shift->r;
+                        my $r = $_[0]->r;
                         return Lemonldap::NG::Handler::Main->redirectFilter(
                             &{ $tsv->{portal} }() . "?url="
-                              . Lemonldap::NG::Handler::Main->encodeUrl( $r,
-                                $u )
+                              . Lemonldap::NG::Handler::Main->encodeUrl($u)
                               . "&logout=1",
                             @_
                         );
                     }
-                );
+                  );
                 1;
             },
             0
